class Core::Portable::FileIterator

Overview

File iterator class usually created on stack with a given directory name. More…

#include <corefile.h>

class FileIterator
{
public:
    // typedefs

    typedef FindFileData Entry;

    // construction

    FileIterator(CStringPtr dirname);

    // methods

    const Entry* next();
};

Detailed Documentation

File iterator class usually created on stack with a given directory name.

Typedefs

typedef FindFileData Entry

File entry.

Methods

const Entry* next()

Advance iterator to next file.

Returns:

current file or null when finished