struct Core::Bluetooth::CharacteristicInfo
Overview
ATTENTION: Interfaces for GATT Peripheral are experimental and not fully implemented on all platforms. More…
#include <coregattperipheral.h> struct CharacteristicInfo { // fields UIDRef uuid = kNullUID; CharacteristicProperties properties = 0; CStringPtr description = ""; };
Detailed Documentation
ATTENTION: Interfaces for GATT Peripheral are experimental and not fully implemented on all platforms.
Do not base production code on it.