struct Core::Zip::CentralDirEndRecord

Overview

End of central directory record. More…

#include <corezipfileformat.h>

struct CentralDirEndRecord
{
    // fields

    uint32 signature;
    uint16 thisDiskNumber;
    uint16 startDiskNumber;
    uint16 numEntriesThisDisk;
    uint16 numEntriesAllDisks;
    uint32 dirSize;
    uint32 dirOffset;
    uint16 commentLength;

    // methods

    bool read(IO::BinaryAccessor& s);
    bool write(IO::BinaryAccessor& s) const;
};

Detailed Documentation

End of central directory record.

Fields

uint32 signature

end of central dir signature 4 bytes (0x06054b50)

uint16 thisDiskNumber

number of this disk 2 bytes

uint16 startDiskNumber

number of the disk with the start of the central directory 2 bytes

uint16 numEntriesThisDisk

total number of entries in the central directory on this disk 2 bytes

uint16 numEntriesAllDisks

total number of entries in the central directory 2 bytes

uint32 dirSize

size of the central directory 4 bytes

uint32 dirOffset

offset of start of central directory with respect to the starting disk number 4 bytes

uint16 commentLength

.ZIP file comment length 2 bytes