struct Core::Zip::CentralDirEndRecord64

Overview

Zip64 End of central directory record. More…

#include <corezipfileformat.h>

struct CentralDirEndRecord64
{
    // fields

    uint32 signature;
    uint64 endRecordSize;
    uint16 versionMadeBy;
    uint16 versionNeeded;
    uint32 thisDiskNumber;
    uint32 startDiskNumber;
    uint64 numEntriesThisDisk;
    uint64 numEntriesAllDisks;
    uint64 dirSize;
    uint64 dirOffset;

    // methods

    bool read(IO::BinaryAccessor& s);
    bool write(IO::BinaryAccessor& s) const;
};

Detailed Documentation

Zip64 End of central directory record.

Fields

uint32 signature

zip64 end of central dir signature 4 bytes (0x06064b50)

uint64 endRecordSize

size of zip64 end of central directory record 8 bytes (should not include the leading 12 bytes: Size = SizeOfFixedFields + SizeOfVariableData - 12.)

uint16 versionMadeBy

version made by 2 bytes

uint16 versionNeeded

version needed to extract 2 bytes

uint32 thisDiskNumber

number of this disk 4 bytes

uint32 startDiskNumber

number of the disk with the start of the central directory 4 bytes

uint64 numEntriesThisDisk

total number of entries in the central directory on this disk 8 bytes

uint64 numEntriesAllDisks

total number of entries in the central directory 8 bytes

uint64 dirSize

size of the central directory 8 bytes

uint64 dirOffset

offset of start of central directory with respect to the starting disk number 8 bytes