class Core::Portable::BaseApplication
Overview
Application base class with support for additional interfaces. More…
#include <coreapplication.h> class BaseApplication: public Core::Portable::TypedObject, public Core::IPropertyHandler { public: // methods DECLARE_CORE_CLASS('BApp', BaseApplication, TypedObject) const; virtual void getProperty(Property& value); virtual void release(); }; // direct descendants class Application;
Inherited Members
public: // typedefs typedef int32 TypeID; // fields static const InterfaceID kIID = 0; // methods virtual void* castTo(TypeID typeId) = 0; virtual void* castTo(TypeID typeId); virtual void setProperty(const Property& value) = 0; virtual void getProperty(Property& value) = 0; virtual void release() = 0;
Detailed Documentation
Application base class with support for additional interfaces.
Can be used directly for legacy applications with non-standard behavior.
Methods
virtual void getProperty(Property& value)
Get property value.
Type and size need to be initialized by caller.
virtual void release()
Release this instance.