enum Core::Zip::GeneralPurposeFlags
Overview
#include <corezipfileformat.h> enum GeneralPurposeFlags { kEncrypted = 1<<0, kStrongEncrypted = 1<<6, kUTF8Encoded = 1<<11, };
Detailed Documentation
Enum Values
kEncrypted
If set, indicates that the file is encrypted.
kStrongEncrypted
Strong encryption.
kUTF8Encoded
Language encoding flag (EFS). If this bit is set, the filename and comment fields for this file must be encoded using UTF-8.