struct Core::Portable::ParamInfo
Overview
Parameter information usually stored in POD-style C arrays and shared among multiple instances of a parameter object. More…
#include <coreparaminfo.h> struct ParamInfo { // enums enum Flags; enum Types; // fields static const int kMaxNameLength = 32; ParamType type; int tag; char name[kMaxNameLength]; ParamValue minValue; ParamValue maxValue; ParamValue midValue; ParamValue defaultValue; ParamValue deltaValue; int flags; CStringPtr unitName; CStringPtr curveName; CStringPtr* stringList; CStringPtr title; CStringPtr shortTitle; // methods void clear(); ParamValue makeValid(ParamValue v) const; };
Detailed Documentation
Parameter information usually stored in POD-style C arrays and shared among multiple instances of a parameter object.
Fields
ParamType type
parameter type
int tag
parameter tag
char name[kMaxNameLength]
parameter name
ParamValue minValue
min range
ParamValue maxValue
max range
ParamValue midValue
additional value for interpolator, not related to min/max
ParamValue defaultValue
default value in min/max range
ParamValue deltaValue
delta value (normalized for kFloat, in min/max range otherwise)
int flags
parameter flags
CStringPtr unitName
formatter name
CStringPtr curveName
interpolator name
CStringPtr* stringList
list of static strings (optional)
CStringPtr title
parameter title (optional - only pointer)
CStringPtr shortTitle
parameter short title (optional - only pointer)