template struct Core::ScopedVar
Sets the var to value when scope is entered and restores the previous value when scope is left.
#include <coreprimitives.h> template <typename T> struct ScopedVar { // fields T& var; T old; // construction ScopedVar(T& var, const T& value); };